Real (imandra-base.Imandra_prelude.Real)

`type t = real`
`val of_int : int -> t`
`val to_int : t -> int`
`val (+) : t -> t -> t`
`val (-) : t -> t -> t`
`val (~-) : t -> t`
`val (*) : t -> t -> t`
`val (/) : t -> t -> t`
`val (<) : t -> t -> bool`
`val (<=) : t -> t -> bool`
`val (>) : t -> t -> bool`
`val (>=) : t -> t -> bool`
`val abs : t -> t`
`val min : t -> t -> t`
`val max : t -> t -> t`
`val mk_of_float : float -> t`
`val mk_of_q : t -> t`
`val mk_of_string : string -> t`
`val to_float : t -> float`
`val of_float : float -> t`
`val compare : t -> t -> Caml.Int.t`
`val pp : Stdlib.Format.formatter -> t -> unit`
`val to_string : t -> string`
`val to_string_approx : t -> string`